@@ -488,9 +488,9 @@ class DataTransformerForm(BaseInlineFormSet):
 
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
-        dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self,
+        dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self.__class__,
                                                              fk_name='parent',
-                                                             extra=1, fields=['id','accessory','parent','type']
+                                                             extra=1, exclude=['updated_at', 'created_at'], form=DataTransform
                                                              )
         form.nested_data_transformer_form = dataTransformerInlineFormset(
             instance=form.instance,
