@@ -389,9 +389,9 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         accessory_form = AccessoryForm(instance=accessory)
         calibration_form = CalibrationForm(initial={'accessory': accessory})
 
-        datatransformerset = inlineformset_factory(DataTransformer, DataTransformer,form=DataTransform,formset=DataTransformerForm,
+        datatransformerset = inlineformset_factory(DataTransformer, DataTransformer,formset=DataTransformerForm,
                                                    fk_name='parent',
-                                                   extra=1, exclude=['updated_at', 'created_at'])
+                                                   extra=1, fields=)
 
         if accessory.has_data_transformer:
             data_transformer = accessory.datatransformer
